==> jc-1.4.0.tar.gz: ppg/code/InitCode.c <==
// public class ppg.code.InitCode

// class file dependencies
// @dep_class bf29ff960d5ec1d0 java_lang_Class
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c80f4aedd95be265 java_lang_String
// @dep_class 94d357637b968dda java_lang_StringBuffer
// @dep_class ff40332975ef3bc9 ppg_code_Code
// @dep_class dc70c1553a4fdfdc ppg_code_InitCode

// header file dependencies
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header java_lang_StringBuffer
// @dep_header ppg_code_InitCode

#include "jc_defs.h"

#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "java/lang/StringBuffer.h"
#include "ppg/code/InitCode.h"

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// public void <init>(java.lang.String)
//

static _jc_linenum _jc_ppg_code_InitCode$linenum_table$_init$c31b894660454d13[];

static const unsigned char _jc_ppg_code_InitCode$param_ptypes$_init$c31b894660454d13[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_VOID };

static _jc_type *const _jc_ppg_code_InitCode$param_types$_init$c31b894660454d13[] = {
	&_jc_java_lang_String$type
};

_jc_method _jc_ppg_code_InitCode$method_info$_init$c31b894660454d13 = {
	.name=			"<init>",
	.signature=		"(Ljava/lang/String;)V",
	.class=			&_jc_ppg_code_InitCode$type,
	.param_types=		&_jc_ppg_code_InitCode$param_types$_init$c31b894660454d13,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_ppg_code_InitCode$param_ptypes$_init$c31b894660454d13,
	.signature_hash=	_JC_JLONG(0xc31b894660454d13),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_ppg_code_InitCode$method$_init$c31b894660454d13,
	.num_parameters=	1,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	2,
	      .table=	_jc_ppg_code_InitCode$linenum_table$_init$c31b894660454d13
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(ppg_code_InitCode, _init$c31b894660454d13);

void
_jc_ppg_code_InitCode$method$_init$c31b894660454d13(_jc_env *const env, _jc_ppg_code_InitCode$object *this, _jc_java_lang_String$object *param0)
{
	struct _jc_ppg_code_InitCode$object *r0;
	struct _jc_java_lang_String$object *r1;

	r0 = this;
	r1 = param0;
	_JC_LINE_NUMBER(6);				// 0
	_JC_REF_FIELD(env, r0, ppg_code_Code, value) = r1;
	_JC_LINE_NUMBER(7);				// 1
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public java.lang.Object clone()
//

static _jc_linenum _jc_ppg_code_InitCode$linenum_table$clone$b75f2713d6705f70[];

static const unsigned char _jc_ppg_code_InitCode$param_ptypes$clone$b75f2713d6705f70[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_ppg_code_InitCode$method_info$clone$b75f2713d6705f70 = {
	.name=			"clone",
	.signature=		"()Ljava/lang/Object;",
	.class=			&_jc_ppg_code_InitCode$type,
	.return_type=		&_jc_java_lang_Object$type,
	.param_ptypes=		&_jc_ppg_code_InitCode$param_ptypes$clone$b75f2713d6705f70,
	.signature_hash=	_JC_JLONG(0xb75f2713d6705f70),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_ppg_code_InitCode$method$clone$b75f2713d6705f70,
	.vtable_index=		_JC_OFFSETOF(struct _jc_ppg_code_InitCode$vtable, ppg_code_InitCode.clone$b75f2713d6705f70) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_ppg_code_InitCode$linenum_table$clone$b75f2713d6705f70
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(ppg_code_InitCode, clone$b75f2713d6705f70);

_jc_java_lang_Object$object *
_jc_ppg_code_InitCode$method$clone$b75f2713d6705f70(_jc_env *const env, _jc_ppg_code_InitCode$object *this)
{
	struct _jc_ppg_code_InitCode$object *r0;
	struct _jc_ppg_code_InitCode$object *r1;
	struct _jc_java_lang_String$object *r2;

	r0 = this;
	_JC_LINE_NUMBER(10);				// 0
	r1 = _JC_NEW(env, ppg_code_InitCode);
	r2 = _JC_REF_FIELD(env, r0, ppg_code_Code, value);
	_JC_EXPLICIT_NULL_CHECK(env, r2);
	_JC_REF_FIELD(env, r1, ppg_code_Code, value) = r2;
	return r1;
}

//
// public java.lang.String toString()
//

static _jc_linenum _jc_ppg_code_InitCode$linenum_table$toString$7ea43b33b80a3070[];

static const unsigned char _jc_ppg_code_InitCode$param_ptypes$toString$7ea43b33b80a3070[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_ppg_code_InitCode$method_info$toString$7ea43b33b80a3070 = {
	.name=			"toString",
	.signature=		"()Ljava/lang/String;",
	.class=			&_jc_ppg_code_InitCode$type,
	.return_type=		&_jc_java_lang_String$type,
	.param_ptypes=		&_jc_ppg_code_InitCode$param_ptypes$toString$7ea43b33b80a3070,
	.signature_hash=	_JC_JLONG(0x7ea43b33b80a3070),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_ppg_code_InitCode$method$toString$7ea43b33b80a3070,
	.vtable_index=		_JC_OFFSETOF(struct _jc_ppg_code_InitCode$vtable, ppg_code_InitCode.toString$7ea43b33b80a3070) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_ppg_code_InitCode$linenum_table$toString$7ea43b33b80a3070
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(ppg_code_InitCode, toString$7ea43b33b80a3070);

_jc_java_lang_String$object *
_jc_ppg_code_InitCode$method$toString$7ea43b33b80a3070(_jc_env *const env, _jc_ppg_code_InitCode$object *this)
{
	struct _jc_ppg_code_InitCode$object *r0;
	struct _jc_java_lang_StringBuffer$object *r1;
	struct _jc_java_lang_String$object *r2;
	struct _jc_java_lang_String$object *r3;
	_jc_char_array *r4;

	// Check for stack overflow
	_JC_STACK_OVERFLOW_CHECK(env);

	r0 = this;
	_JC_LINE_NUMBER(14);				// 0
	r1 = _JC_NEW(env, java_lang_StringBuffer);
	r4 = _JC_NEW_PRIM_ARRAY(env, char, 1, 16);
	_JC_REF_FIELD(env, r1, java_lang_StringBuffer, value) = r4;
	r1 = _JC_INVOKE_NONVIRTUAL(env, java_lang_StringBuffer, append$7d7ff98bb1f0cb55, 0, r1, _JC_STRING(env, "init code {:\n"));
	r2 = _JC_REF_FIELD(env, r0, ppg_code_Code, value);
	r1 = _JC_INVOKE_NONVIRTUAL(env, java_lang_StringBuffer, append$7d7ff98bb1f0cb55, 0, r1, r2);
	r1 = _JC_INVOKE_NONVIRTUAL(env, java_lang_StringBuffer, append$7d7ff98bb1f0cb55, 0, r1, _JC_STRING(env, "\n:}\n"));
	r3 = _JC_NEW(env, java_lang_String);
	_JC_INVOKE_NONVIRTUAL(env, java_lang_String, _init$aa54f0755ac8f3ce, 0, r3, r1);
	return r3;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_ppg_code_InitCode$methods[] = {
	&_jc_ppg_code_InitCode$method_info$_init$c31b894660454d13,
	&_jc_ppg_code_InitCode$method_info$clone$b75f2713d6705f70,
	&_jc_ppg_code_InitCode$method_info$toString$7ea43b33b80a3070
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_ppg_code_InitCode$instanceof_hash_bucket_73[] = {
	&_jc_ppg_code_Code$type,
	_JC_NULL
};
static _jc_type *const _jc_ppg_code_InitCode$instanceof_hash_bucket_92[] = {
	&_jc_ppg_code_InitCode$type,
	_JC_NULL
};
static _jc_type *const _jc_ppg_code_InitCode$instanceof_hash_bucket_113[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_ppg_code_InitCode$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[73]=	_jc_ppg_code_InitCode$instanceof_hash_bucket_73,
	[92]=	_jc_ppg_code_InitCode$instanceof_hash_bucket_92,
	[113]=	_jc_ppg_code_InitCode$instanceof_hash_bucket_113
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_ppg_code_InitCode$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0xbf29ff960d5ec1d0) },
	{ "java/lang/Object",	_JC_JLONG(0x2a7152deee1944f1) },
	{ "java/lang/String",	_JC_JLONG(0xc80f4aedd95be265) },
	{ "java/lang/StringBuffer",	_JC_JLONG(0x94d357637b968dda) },
	{ "ppg/code/Code",	_JC_JLONG(0xff40332975ef3bc9) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_ppg_code_InitCode$vtype _jc_ppg_code_InitCode$type = {
    .type= {
	.name=			"ppg/code/InitCode",
	.superclass=		&_jc_ppg_code_Code$type,
	.access_flags=		_JC_ACC_PUBLIC,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		17,
		.hash=			_JC_JLONG(0xdc70c1553a4fdfdc),
		.source_file=		"InitCode.java",
		.instance_size=		sizeof(_jc_ppg_code_InitCode$refs) + sizeof(_jc_ppg_code_InitCode$object),
		.num_virtual_refs=	1,
		.num_methods=		sizeof(_jc_ppg_code_InitCode$methods) / sizeof(*_jc_ppg_code_InitCode$methods),
		.methods=		_jc_ppg_code_InitCode$methods,
		.instanceof_hash_table=	_jc_ppg_code_InitCode$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_ppg_code_InitCode$class_depends) / sizeof(*_jc_ppg_code_InitCode$class_depends),
		.class_depends=		_jc_ppg_code_InitCode$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=			// overridden
		&_jc_ppg_code_InitCode$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=			// overridden
		&_jc_ppg_code_InitCode$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.ppg_code_Code= {
	    .append$e81cc402fc833404=
		&_jc_ppg_code_Code$method$append$e81cc402fc833404,
	    .clone$b75f2713d6705f70=			// overridden
		&_jc_ppg_code_InitCode$method$clone$b75f2713d6705f70,
	    .prepend$8da17169eb296f99=
		&_jc_ppg_code_Code$method$prepend$8da17169eb296f99,
	    .toString$7ea43b33b80a3070=			// overridden
		&_jc_ppg_code_InitCode$method$toString$7ea43b33b80a3070,
	},
	.ppg_code_InitCode= {
	    .clone$b75f2713d6705f70=
		&_jc_ppg_code_InitCode$method$clone$b75f2713d6705f70,
	    .toString$7ea43b33b80a3070=
		&_jc_ppg_code_InitCode$method$toString$7ea43b33b80a3070,
	},
    }
};

==> jc-1.4.5.tar.gz: ppg/code/InitCode.c <==
// public class ppg.code.InitCode

// class file dependencies
// @dep_class 764eb76bc6714ae3 java_lang_Class
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 195095aa45046bea java_lang_String
// @dep_class 94d357637b968dda java_lang_StringBuffer
// @dep_class ff40332975ef3bc9 ppg_code_Code
// @dep_class dc70c1553a4fdfdc ppg_code_InitCode

// header file dependencies
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header java_lang_StringBuffer
// @dep_header ppg_code_InitCode

#include "jc_defs.h"

#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "java/lang/StringBuffer.h"
#include "ppg/code/InitCode.h"

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// public void <init>(java.lang.String)
//

static _jc_linenum _jc_ppg_code_InitCode$linenum_table$_init$c31b894660454d13[];

static const unsigned char _jc_ppg_code_InitCode$param_ptypes$_init$c31b894660454d13[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_VOID };

static _jc_type *const _jc_ppg_code_InitCode$param_types$_init$c31b894660454d13[] = {
	&_jc_java_lang_String$type
};

_jc_method _jc_ppg_code_InitCode$method_info$_init$c31b894660454d13 = {
	.name=			"<init>",
	.signature=		"(Ljava/lang/String;)V",
	.class=			&_jc_ppg_code_InitCode$type,
	.param_types=		&_jc_ppg_code_InitCode$param_types$_init$c31b894660454d13,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_ppg_code_InitCode$param_ptypes$_init$c31b894660454d13,
	.signature_hash=	_JC_JLONG(0xc31b894660454d13),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_ppg_code_InitCode$method$_init$c31b894660454d13,
	.num_parameters=	1,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	2,
	      .table=	_jc_ppg_code_InitCode$linenum_table$_init$c31b894660454d13
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(ppg_code_InitCode, _init$c31b894660454d13);

void _JC_JCNI_ATTR
_jc_ppg_code_InitCode$method$_init$c31b894660454d13(_jc_env *const env, _jc_ppg_code_InitCode$object *this, _jc_java_lang_String$object *param0)
{
	struct _jc_ppg_code_InitCode$object *r0;
	struct _jc_java_lang_String$object *r1;

	r0 = this;
	r1 = param0;
	_JC_LINE_NUMBER(6);				// 0
	_JC_REF_FIELD(env, r0, ppg_code_Code, value) = r1;
	_JC_LINE_NUMBER(7);				// 1
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public java.lang.Object clone()
//

static _jc_linenum _jc_ppg_code_InitCode$linenum_table$clone$b75f2713d6705f70[];

static const unsigned char _jc_ppg_code_InitCode$param_ptypes$clone$b75f2713d6705f70[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_ppg_code_InitCode$method_info$clone$b75f2713d6705f70 = {
	.name=			"clone",
	.signature=		"()Ljava/lang/Object;",
	.class=			&_jc_ppg_code_InitCode$type,
	.return_type=		&_jc_java_lang_Object$type,
	.param_ptypes=		&_jc_ppg_code_InitCode$param_ptypes$clone$b75f2713d6705f70,
	.signature_hash=	_JC_JLONG(0xb75f2713d6705f70),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_ppg_code_InitCode$method$clone$b75f2713d6705f70,
	.vtable_index=		_JC_OFFSETOF(struct _jc_ppg_code_InitCode$vtable, ppg_code_InitCode.clone$b75f2713d6705f70) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_ppg_code_InitCode$linenum_table$clone$b75f2713d6705f70
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(ppg_code_InitCode, clone$b75f2713d6705f70);

_jc_java_lang_Object$object * _JC_JCNI_ATTR
_jc_ppg_code_InitCode$method$clone$b75f2713d6705f70(_jc_env *const env, _jc_ppg_code_InitCode$object *this)
{
	struct _jc_ppg_code_InitCode$object *r0;
	struct _jc_ppg_code_InitCode$object *r1;
	struct _jc_java_lang_String$object *r2;

	r0 = this;
	_JC_LINE_NUMBER(10);				// 0
	r1 = _JC_NEW(env, ppg_code_InitCode);
	r2 = _JC_REF_FIELD(env, r0, ppg_code_Code, value);
	_JC_EXPLICIT_NULL_CHECK(env, r2);
	_JC_REF_FIELD(env, r1, ppg_code_Code, value) = r2;
	return r1;
}

//
// public java.lang.String toString()
//

static _jc_linenum _jc_ppg_code_InitCode$linenum_table$toString$7ea43b33b80a3070[];

static const unsigned char _jc_ppg_code_InitCode$param_ptypes$toString$7ea43b33b80a3070[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_ppg_code_InitCode$method_info$toString$7ea43b33b80a3070 = {
	.name=			"toString",
	.signature=		"()Ljava/lang/String;",
	.class=			&_jc_ppg_code_InitCode$type,
	.return_type=		&_jc_java_lang_String$type,
	.param_ptypes=		&_jc_ppg_code_InitCode$param_ptypes$toString$7ea43b33b80a3070,
	.signature_hash=	_JC_JLONG(0x7ea43b33b80a3070),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_ppg_code_InitCode$method$toString$7ea43b33b80a3070,
	.vtable_index=		_JC_OFFSETOF(struct _jc_ppg_code_InitCode$vtable, ppg_code_InitCode.toString$7ea43b33b80a3070) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_ppg_code_InitCode$linenum_table$toString$7ea43b33b80a3070
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(ppg_code_InitCode, toString$7ea43b33b80a3070);

_jc_java_lang_String$object * _JC_JCNI_ATTR
_jc_ppg_code_InitCode$method$toString$7ea43b33b80a3070(_jc_env *const env, _jc_ppg_code_InitCode$object *this)
{
	struct _jc_ppg_code_InitCode$object *r0;
	struct _jc_java_lang_StringBuffer$object *r1;
	struct _jc_java_lang_String$object *r2;
	struct _jc_java_lang_String$object *r3;
	_jc_char_array *r4;

	// Check for stack overflow
	_JC_STACK_OVERFLOW_CHECK(env);

	r0 = this;
	_JC_LINE_NUMBER(14);				// 0
	r1 = _JC_NEW(env, java_lang_StringBuffer);
	r4 = _JC_NEW_PRIM_ARRAY(env, char, 1, 16);
	_JC_REF_FIELD(env, r1, java_lang_StringBuffer, value) = r4;
	r1 = _JC_INVOKE_NONVIRTUAL(env, java_lang_StringBuffer, append$7d7ff98bb1f0cb55, 0, r1, _JC_STRING(env, "init code {:\n"));
	r2 = _JC_REF_FIELD(env, r0, ppg_code_Code, value);
	r1 = _JC_INVOKE_NONVIRTUAL(env, java_lang_StringBuffer, append$7d7ff98bb1f0cb55, 0, r1, r2);
	r1 = _JC_INVOKE_NONVIRTUAL(env, java_lang_StringBuffer, append$7d7ff98bb1f0cb55, 0, r1, _JC_STRING(env, "\n:}\n"));
	r3 = _JC_NEW(env, java_lang_String);
	_JC_INVOKE_NONVIRTUAL(env, java_lang_String, _init$aa54f0755ac8f3ce, 0, r3, r1);
	return r3;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_ppg_code_InitCode$methods[] = {
	&_jc_ppg_code_InitCode$method_info$_init$c31b894660454d13,
	&_jc_ppg_code_InitCode$method_info$clone$b75f2713d6705f70,
	&_jc_ppg_code_InitCode$method_info$toString$7ea43b33b80a3070
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_ppg_code_InitCode$instanceof_hash_bucket_73[] = {
	&_jc_ppg_code_Code$type,
	_JC_NULL
};
static _jc_type *const _jc_ppg_code_InitCode$instanceof_hash_bucket_92[] = {
	&_jc_ppg_code_InitCode$type,
	_JC_NULL
};
static _jc_type *const _jc_ppg_code_InitCode$instanceof_hash_bucket_101[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_ppg_code_InitCode$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[73]=	_jc_ppg_code_InitCode$instanceof_hash_bucket_73,
	[92]=	_jc_ppg_code_InitCode$instanceof_hash_bucket_92,
	[101]=	_jc_ppg_code_InitCode$instanceof_hash_bucket_101
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_ppg_code_InitCode$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0x764eb76bc6714ae3) },
	{ "java/lang/Object",	_JC_JLONG(0x1c4f1fc002fc96e5) },
	{ "java/lang/String",	_JC_JLONG(0x195095aa45046bea) },
	{ "java/lang/StringBuffer",	_JC_JLONG(0x94d357637b968dda) },
	{ "ppg/code/Code",	_JC_JLONG(0xff40332975ef3bc9) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_ppg_code_InitCode$vtype _jc_ppg_code_InitCode$type = {
    .type= {
	.name=			"ppg/code/InitCode",
	.superclass=		&_jc_ppg_code_Code$type,
	.access_flags=		_JC_ACC_PUBLIC,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		17,
		.hash=			_JC_JLONG(0xdc70c1553a4fdfdc),
		.source_file=		"InitCode.java",
		.instance_size=		sizeof(_jc_ppg_code_InitCode$refs) + sizeof(_jc_ppg_code_InitCode$object),
		.num_virtual_refs=	1,
		.num_methods=		sizeof(_jc_ppg_code_InitCode$methods) / sizeof(*_jc_ppg_code_InitCode$methods),
		.methods=		_jc_ppg_code_InitCode$methods,
		.instanceof_hash_table=	_jc_ppg_code_InitCode$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_ppg_code_InitCode$class_depends) / sizeof(*_jc_ppg_code_InitCode$class_depends),
		.class_depends=		_jc_ppg_code_InitCode$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=			// overridden
		&_jc_ppg_code_InitCode$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=			// overridden
		&_jc_ppg_code_InitCode$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.ppg_code_Code= {
	    .append$e81cc402fc833404=
		&_jc_ppg_code_Code$method$append$e81cc402fc833404,
	    .clone$b75f2713d6705f70=			// overridden
		&_jc_ppg_code_InitCode$method$clone$b75f2713d6705f70,
	    .prepend$8da17169eb296f99=
		&_jc_ppg_code_Code$method$prepend$8da17169eb296f99,
	    .toString$7ea43b33b80a3070=			// overridden
		&_jc_ppg_code_InitCode$method$toString$7ea43b33b80a3070,
	},
	.ppg_code_InitCode= {
	    .clone$b75f2713d6705f70=
		&_jc_ppg_code_InitCode$method$clone$b75f2713d6705f70,
	    .toString$7ea43b33b80a3070=
		&_jc_ppg_code_InitCode$method$toString$7ea43b33b80a3070,
	},
    }
};
